function appointment_type_behaviour(checkboxes, outObject, api_call) {
    var appointment_types_data = null;

    var global_sequential_time = 0;
    var global_time = 0;
    var global_parallel_time = 0;

    function recompute_parallel_time(object) {
        var result = 0;
        var object_id = -1;
        if (object) {
            object_id = object.attr('id');
        }
        $.each(checkboxes, function (index, value) {
            var checkbox = $(value);
            var val = parseInt(checkbox.attr('value'));
            if ((checkbox.is(":checked") && checkbox.attr('id') != object_id) || (!checkbox.is(":checked") && checkbox.attr('id') == object_id)) {
                var appointment_type = appointment_types_data[val];
                if (appointment_type.can_be_parallelized) {
                    result = Math.max(result, appointment_type.default_duration)
                }
            }
        });
        return result;
    }

    function recompute_sequential_time(object) {
        var result = 0;
        var object_id = -1;
        if (object) {
            object_id = object.attr('id');
        }
        $.each(checkboxes, function (index, value) {
            var checkbox = $(value);
            var val = parseInt(checkbox.attr('value'));
            if ((checkbox.is(":checked") && checkbox.attr('id') != object_id) || (!checkbox.is(":checked") && checkbox.attr('id') == object_id)) {
                var appointment_type = appointment_types_data[val];
                if (!appointment_type.can_be_parallelized) {
                    result += appointment_type.default_duration
                }
            }
        });
        return result;
    }

    function compute_time(object) {
        var val = parseInt(object.attr('value'));
        var time = 0;
        var appointment_type = appointment_types_data[val];
        if (appointment_type == null) {
            console.log("Cannot find appointment type with id: " + val);
        } else {
            time = appointment_type.default_duration;
            if (appointment_type.can_be_parallelized) {
                if (object.is(":checked")) {
                    global_parallel_time = Math.max(global_parallel_time, time);
                } else {
                    global_parallel_time = recompute_parallel_time();
                }
            } else {
                if (object.is(":checked")) {
                    global_sequential_time += time;
                } else {
                    global_sequential_time -= time;
                }
            }
            global_time = Math.max(global_parallel_time, global_sequential_time);
            $(outObject).val(global_time + "");
        }

    }


    $(checkboxes).change(function () {
        var object = $(this);
        if (appointment_types_data === null) {
            $.get(api_call, function (data) {
                appointment_types_data = {};
                $.each(data.appointment_types, function (index, appointment_type) {
                    appointment_types_data[appointment_type.id] = appointment_type;
                });
                global_parallel_time = recompute_parallel_time(object);
                global_sequential_time = recompute_sequential_time(object);
                compute_time(object)
            });
        } else {
            compute_time(object);
        }

    });
}

/**
 * When any option is selected in flying_team_select, location value is set to flying team.
 *
 * @param flying_team_select
 * @param location_select
 */
function appointment_flying_team_place_behaviour(flying_team_select, location_select) {
    $(flying_team_select).change(function () {
        if ($(this).val() != "") {
            $(location_select).find('option').each(function () {
                if ("Flying Team" == $(this).html()) {
                    $(location_select).val($(this).val());
                }
            });
        }
    });
}

function get_calendar_events_function(source, allow_url_redirection) {
    if (allow_url_redirection === undefined) {
        allow_url_redirection = false;
    }
    return function (start, end, timezone, callback) {
        $.ajax({
            data: {
                // our hypothetical feed requires UNIX timestamps
                start_date: start.format(),
                end_date: end.format()
            },
            url: source,
            success: function (doc) {
                var events = [];
                for (var i = 0; i < doc.data.length; i++) {

                    const entry = doc.data[i];
                    var title = entry.subject;
                    if (title != "") {
                        title += " (" + entry.nd_number + "); type: " + entry.type;
                    } else {
                        title = entry.title
                    }
                    var event = {
                        title: title,
                        start: entry.datetime_when,
                        end: entry.datetime_until,
                        id: entry.id,
                        color: entry.color,
                        nd_number: entry.nd_number,
                        screening_number: entry.screening_number,
                        phone_number: entry.phone_number,
                        appointment_types: entry.appointment_types
                    };
                    if (allow_url_redirection) {
                        event["url"] = entry.url;
                    }
                    events.push(event)
                }
                callback(events);
            }
        });
    }
}
