# coding=utf-8
from django.shortcuts import redirect, get_object_or_404

from . import wrap_response
from ..forms import WorkerAddForm, WorkerEditForm, AvailabilityAddForm, AvailabilityEditForm, HolidayAddForm
from ..models import Worker, Availability, Holiday
from ..models.constants import WEEKDAY_CHOICES


def doctors(request):
    doctors_list = Worker.objects.order_by('-last_name')
    context = {
        'doctors_list': doctors_list
    }

    return wrap_response(request, "doctors/index.html", context)


def doctor_add(request):
    if request.method == 'POST':
        form = WorkerAddForm(request.POST, request.FILES)
        if form.is_valid():
            form.save()
            return redirect('web.views.doctors')
    else:
        form = WorkerAddForm()

    return wrap_response(request, 'doctors/add.html', {'form': form})


def doctor_edit(request, doctor_id):
    the_doctor = get_object_or_404(Worker, id=doctor_id)
    if request.method == 'POST':
        form = WorkerEditForm(request.POST, request.FILES, instance=the_doctor)
        if form.is_valid():
            form.save()
            return redirect('web.views.doctors')
    else:
        form = WorkerEditForm(instance=the_doctor)
    availabilities = Availability.objects.filter(person=doctor_id).order_by('day_number', 'available_from');
    holidays = Holiday.objects.filter(person=doctor_id).order_by('-datetime_start');
    return wrap_response(request, 'doctors/edit.html',
                         {
                             'form': form,
                             'availabilities': availabilities,
                             'holidays': holidays,
                             'doctor_id': doctor_id,
                             'weekdays': WEEKDAY_CHOICES
                         })


def doctor_availability_delete(request, availability_id):
    availability = Availability.objects.filter(id=availability_id)
    doctor_id = availability[0].person.id
    availability.delete()
    return redirect(doctor_edit, doctor_id=doctor_id)


def doctor_availability_add(request, doctor_id):
    doctors = Worker.objects.filter(id=doctor_id)
    doctor = None
    if len(doctors) > 0:
        doctor = doctors[0]
    if request.method == 'POST':
        form = AvailabilityAddForm(request.POST, request.FILES)
        if form.is_valid():
            form.save()
            return redirect(doctor_edit, doctor_id=doctor_id)
    else:
        form = AvailabilityAddForm(initial={'person': doctor})
    return wrap_response(request, 'doctors/add_availability.html',
                         {
                             'form': form,
                             'doctor_id': doctor_id
                         })


def doctor_availability_edit(request, availability_id):
    availability = get_object_or_404(Availability, id=availability_id)
    if request.method == 'POST':
        form = AvailabilityEditForm(request.POST, request.FILES, instance=availability)
        if form.is_valid():
            form.save()
            return redirect(doctor_edit, doctor_id=availability.person_id)
    else:
        form = AvailabilityEditForm(instance=availability)
    return wrap_response(request, 'doctors/edit_availability.html',
                         {
                             'form': form,
                             'availability_id': availability_id,
                             'doctor_id': availability.person_id,
                         })


def doctor_holiday_delete(request, holiday_id):
    holiday = Holiday.objects.filter(id=holiday_id)
    doctor_id = holiday[0].person.id
    holiday.delete()
    return redirect(doctor_edit, doctor_id=doctor_id)


def doctor_holiday_add(request, doctor_id):
    doctors = Worker.objects.filter(id=doctor_id)
    doctor = None
    if len(doctors) > 0:
        doctor = doctors[0]
    if request.method == 'POST':
        form = HolidayAddForm(request.POST, request.FILES)
        if form.is_valid():
            form.save()
            return redirect(doctor_edit, doctor_id=doctor_id)
    else:
        form = HolidayAddForm(initial={'person': doctor})
    return wrap_response(request, 'doctors/add_holiday.html',
                         {
                             'form': form,
                             'doctor_id': doctor_id
                         })
